' CustSync.vbs
' Synchronizes files based on filespecs entered manually or in a file.
' Created       2004-05-07
' Last Modified 2008-09-18
' Written by Stephen Tuggy
' Version 0.2.0.1
' For Microsoft Windows Scripting Host 5.6

' Copyright  2008 Stephen Tuggy
' 
' This file is part of CustSync.
' 
' CustSync is free software: you can redistribute it and/or modify it under
' the terms of the GNU General Public License as published by the Free
' Software Foundation, either version 3 of the license, or (at your option)
' any later version.
' 
' CustSync is distributed in the hope that it will be useful, but WITHOUT ANY
' WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
' FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
' details.
' 
' You should have received a copy of the GNU General Public License along with
' CustSync. If not, see <http://www.gnu.org/licenses/>.

Option Explicit

Const ForReading = 1
Const strcXCopyCmd = "XCOPY ", strcSwitches = " /D /F /Y"

Dim fso, WSHShell, args, ts, strLine1, strLine2

Set fso = CreateObject("Scripting.FileSystemObject")
Set WSHShell = CreateObject("WScript.Shell")

Set args = WScript.Arguments
If args.Count > 0 Then
    If fso.FileExists(args(0)) Then
        Set ts = fso.OpenTextFile(args(0), ForReading)
    Else
        MsgBox "File " & args(0) & " does not exist.", vbCritical, WScript.ScriptName
        WScript.Quit 1
    End If
Else
    Set ts = WScript.StdIn
End If

Do Until ts.AtEndOfStream

    ' Get one pair of synchronization paths.
    Do
        If ts.AtEndOfStream Then
            WScript.Quit
        End If
        strLine1 = ts.ReadLine
    Loop While strLine1 = ""
    Do
        If ts.AtEndOfStream Then
            MsgBox "Wrong number of lines in input.", vbExclamation, _
                    WScript.ScriptName
            WScript.Quit 2
        End If
        strLine2 = ts.ReadLine
    Loop While strLine2 = ""

    OneWaySync strLine1, strLine2

    OneWaySync strLine2, strLine1

Loop

' Exit normally.
WScript.Quit 0

Private Sub OneWaySync(strPath1, strPath2)
    Dim strCommand, execResult, msgResult
    
    strCommand = strcXCopyCmd & strPath1 & " " & strPath2 & strcSwitches
    Do
        execResult = WSHShell.Run(strCommand, , True)
        
        If execResult = 0 Then
            Exit Do
        End If
        
        ' Otherwise ...
        msgResult = MsgBox("The command """ & strCommand _
                & """ returned error code " & execResult _
                & ". Choose Abort to cancel all specified synchronizations, " _
                & "Retry to retry this one, or Ignore to try the next one.", _
                vbAbortRetryIgnore + vbExclamation, WScript.ScriptName)
        If msgResult = vbAbort Then
            WScript.Quit 2
        ElseIf msgResult = vbRetry Then
            
        ElseIf msgResult = vbIgnore Then
            Exit Do
        End If
        
    Loop
    
End Sub
